@@ -45,7 +45,6 @@ from typing import (
     Callable,
     Dict,
     FrozenSet,
-    Optional,
     TypeVar,
 )
 
@@ -205,7 +204,7 @@ class SchemaClient:
             ),
             None,
         )
-        id_args: Dict[str, Optional[str]] = {"schema": schema.name}
+        id_args: Dict[str, str] = {"schema": schema.name}
         args: Dict[str, PrimitiveVal] = (
             {"quota": policy.quota.value}
             if isinstance(policy.quota, Quota)
