@@ -360,7 +360,11 @@ class TableClient:
         create = self.exist(target).bind(
             lambda b: self.create_like(source, target) if not b else nothing
         )
-        return create + self.move_data(source, target) + self.delete(source)
+        return (
+            create
+            + self.move_data(source, target)
+            + self.delete_cascade(source)
+        )
 
     def migrate(self, source: TableId, target: TableId) -> Cmd[None]:
         """
